Quick Start
===========

1. Install Tamarco

To install Tamarco, simply run this command in your terminal of choice. Allowed Python versions
are Python >= 3.6. Recommended version is Python 3.7::

    $ pip3 install tamarco

Start a project
---------------

Use Tamarco to start a new project. Use the following command and fill the data requested::

    $ tamarco start_project

Write your microservice
-----------------------

Start writing the microservice code inside the project folder, in `microservice.py`.

Run the microservice
--------------------

Run the microservice with the following command::

    $ python3 app.py
